@@ -21,7 +21,7 @@ class FWTP:
     def __enter__(self):
         self._connection = connect(**self._conn_dict)
         self._connection.autocommit = True
-        self._cursor = self._connection.cursor
+        self._cursor = self._connection.cursor()
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb) -> None:
